@@ -44,8 +44,10 @@
 //NOTE: the \\s in the expressions is needed, because Maxima seems to sometimes insert newlines/spaces between the letters
 //maybe this is caused by some behaviour if the Prompt is split into multiple "readStdout" calls
 //the Expressions are encapsulated in () to allow capturing for the text
-const QRegExp MaximaSession::MaximaOutputPrompt=QRegExp(QLatin1String("(\\(\\s*%\\s*o\\s*[0-9\\s]*\\))")); //Text, maxima outputs, before any output
-const QRegExp MaximaSession::MaximaInputPrompt = QRegExp(QLatin1String("(\\(\\s*%\\s*i\\s*[0-9\\s]*\\))"));
+const QRegularExpression MaximaSession::MaximaOutputPrompt =
+            QRegularExpression(QStringLiteral("(\\(\\s*%\\s*o\\s*[0-9\\s]*\\))")); //Text, maxima outputs, before any output
+const QRegularExpression MaximaSession::MaximaInputPrompt =
+            QRegularExpression(QStringLiteral("(\\(\\s*%\\s*i\\s*[0-9\\s]*\\))"));
 
 
 MaximaSession::MaximaSession( Cantor::Backend* backend ) : Session(backend),
@@ -190,7 +192,6 @@ void MaximaSession::reportProcessError(QProcess::ProcessError e)
 void MaximaSession::currentExpressionChangedStatus(Cantor::Expression::Status status)
 {
     Cantor::Expression* expression = expressionQueue().first();
-    const QString& cmd = expression->command();
     qDebug() << "expression status changed: command = " << expression->command() << ", status = " << status;
 
     switch (status)
